#
# This is the SPEC file for creating binary RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
# Copyright (C) 2010  Rafal Wojtczuk  <rafal@invisiblethingslab.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, see <https://www.gnu.org/licenses/>.
#
#

Name:		qubes-core-qrexec
Version:	4.2.19
Release:	1%{dist}
Summary:	The Qubes qrexec files (common files)

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		https://www.qubes-os.org

BuildRequires:	gcc
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
# for building documentation
BuildRequires:	python3dist(sphinx)
BuildRequires:	python%{python3_pkgversion}-recommonmark
BuildRequires:	qubes-libvchan-devel
%if 0%{?is_opensuse}
BuildRequires:  python-rpm-macros
%else
BuildRequires:  python%{python3_pkgversion}-rpm-macros
%endif

Requires:   python%{python3_pkgversion}
Requires:   python%{python3_pkgversion}-gbulb
%if 0%{?is_opensuse}
Requires:   python%{python3_pkgversion}-pyinotify
%else
Requires:   python%{python3_pkgversion}-inotify
%endif
Conflicts:  qubes-utils-libs < 4.1.0
Conflicts:  qubes-core-agent-qrexec < 4.1.0
Conflicts:  qubes-core-dom0 < 4.1.10
Conflicts:  qubes-core-dom0-linux < 4.1.5
Conflicts:  qubes-gui-agent < 4.1.6
Conflicts:  qubes-gpg-split < 2.0.45
Conflicts:  qubes-gui-daemon < 4.1.4
Conflicts:  qubes-input-proxy < 1.0.17
Conflicts:  qubes-pdf-converter < 2.1.7
Conflicts:  qubes-usb-proxy < 1.0.28

Source0: qubes-core-qrexec-%{version}.tar.gz

%description
The Qubes qrexec files for installation on both dom0 and qube.

%package libs
Summary:    Libraries for qubes-qrexec
Conflicts:  qubes-utils-libs < 4.1.0

%description libs
Libraries for qubes-qrexec

%package devel
Summary:    Development headers for qubes-qrexec
Requires:   %{name}-libs

%description devel
Development header and files for qubes-qrexec

%prep
%setup -qn qubes-core-qrexec-%{version}

%build
%{?set_build_flags}
make all-base PYTHON=%{__python3}
make -C doc PYTHON=python3 SPHINXBUILD=sphinx-build man

%install
make install-base \
    INCLUDEDIR=%{_includedir} \
    LIBDIR=%{_libdir} \
    SYSCONFDIR=%{_sysconfdir} \
    UNITDIR=%{_unitdir} \
    PYTHON_SITEPATH=%{python3_sitelib} \
    PYTHON=%{__python3} \
    DESTDIR=$RPM_BUILD_ROOT

make -C doc \
    DESTDIR=$RPM_BUILD_ROOT \
    SPHINXBUILD=sphinx-build \
    install

mkdir -p $RPM_BUILD_ROOT/etc/qubes/rpc-config

# /qubes-rpc/policy.{Ask,Notify} intentionally points to files created at
# runtime (in /var/run)
export NO_BRP_STALE_LINK_ERROR=yes

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%files
%defattr(-,root,root,-)

%{_bindir}/qrexec-legacy-convert
%{_bindir}/qrexec-policy-exec
%{_bindir}/qrexec-policy-agent
%{_bindir}/qrexec-policy-graph
%{_bindir}/qrexec-policy-restore
%{_bindir}/qrexec-policy-daemon
%{_bindir}/qubes-policy
%{_bindir}/qubes-policy-admin
%{_bindir}/qubes-policy-editor
%{_bindir}/qubes-policy-lint
%{_bindir}/qrexec-policy

%dir /usr/lib/qubes
/usr/lib/qubes/qubes-rpc-multiplexer
/usr/lib/qubes/qrexec-policy-agent-autostart

%dir %{_sysconfdir}/qubes
%dir %{_sysconfdir}/qubes/rpc-config
%dir %{_sysconfdir}/qubes-rpc
%{_sysconfdir}/qubes-rpc/policy.Ask
%{_sysconfdir}/qubes-rpc/policy.Notify

%{_sysconfdir}/xdg/autostart/qrexec-policy-agent.desktop

%dir %{python3_sitelib}/qrexec-*.egg-info
%{python3_sitelib}/qrexec-*.egg-info/*

%dir %{python3_sitelib}/qrexec
%dir %{python3_sitelib}/qrexec/__pycache__
%{python3_sitelib}/qrexec/__pycache__/*
%{python3_sitelib}/qrexec/__init__.py
%{python3_sitelib}/qrexec/client.py
%{python3_sitelib}/qrexec/exc.py
%{python3_sitelib}/qrexec/utils.py
%{python3_sitelib}/qrexec/server.py

%dir %{python3_sitelib}/qrexec/policy
%dir %{python3_sitelib}/qrexec/policy/__pycache__
%{python3_sitelib}/qrexec/policy/__pycache__/*
%{python3_sitelib}/qrexec/policy/__init__.py
%{python3_sitelib}/qrexec/policy/admin.py
%{python3_sitelib}/qrexec/policy/admin_client.py
%{python3_sitelib}/qrexec/policy/parser.py
%{python3_sitelib}/qrexec/policy/parser_compat.py
%{python3_sitelib}/qrexec/policy/utils.py

%dir %{python3_sitelib}/qrexec/tools
%dir %{python3_sitelib}/qrexec/tools/__pycache__
%{python3_sitelib}/qrexec/tools/__pycache__/*
%{python3_sitelib}/qrexec/tools/__init__.py
%{python3_sitelib}/qrexec/tools/qubes_policy.py
%{python3_sitelib}/qrexec/tools/qubes_policy_admin.py
%{python3_sitelib}/qrexec/tools/qubes_policy_editor.py
%{python3_sitelib}/qrexec/tools/qubes_policy_lint.py
%{python3_sitelib}/qrexec/tools/qrexec_legacy_convert.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_agent.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_exec.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_daemon.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_graph.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_restore.py

%dir %{python3_sitelib}/qrexec/tests
%dir %{python3_sitelib}/qrexec/tests/__pycache__
%{python3_sitelib}/qrexec/tests/__pycache__/*
%{python3_sitelib}/qrexec/tests/__init__.py
%{python3_sitelib}/qrexec/tests/cli.py
%{python3_sitelib}/qrexec/tests/gtkhelpers.py
%{python3_sitelib}/qrexec/tests/rpcconfirmation.py
%{python3_sitelib}/qrexec/tests/policy_parser.py
%{python3_sitelib}/qrexec/tests/qrexec_policy_daemon.py
%{python3_sitelib}/qrexec/tests/qrexec_legacy_convert.py
%{python3_sitelib}/qrexec/tests/policy_cache.py
%{python3_sitelib}/qrexec/tests/policy_graph.py
%{python3_sitelib}/qrexec/tests/server.py
%{python3_sitelib}/qrexec/tests/policy_admin.py

%dir %{python3_sitelib}/qrexec/tests/socket
%dir %{python3_sitelib}/qrexec/tests/socket/__pycache__
%{python3_sitelib}/qrexec/tests/socket/__pycache__/*
%{python3_sitelib}/qrexec/tests/socket/__init__.py
%{python3_sitelib}/qrexec/tests/socket/agent.py
%{python3_sitelib}/qrexec/tests/socket/daemon.py
%{python3_sitelib}/qrexec/tests/socket/qrexec.py
%{python3_sitelib}/qrexec/tests/socket/util.py

%dir %{python3_sitelib}/qrexec/glade
%{python3_sitelib}/qrexec/glade/RPCConfirmationWindow.glade

%{_datadir}/man/man1/qubes-core-qrexec.1.gz

%files devel
%{_includedir}/qrexec.h
%{_includedir}/libqrexec-utils.h
%{_libdir}/libqrexec-utils.so

%files libs
%{_libdir}/libqrexec-utils.so.*

%changelog
* Thu May 09 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qrexec

* Thu May 09 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 43f49f0
- version 4.2.19

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 64d6e06
- Test if a service config directory itself is invalid

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c6f9a2f
- Fail early if the service config cannot be found

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 9114fb3
- Avoid passing stderr_fd to handle_data_client

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 8b683a8
- tests: do not write to maybe-closed socket

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a60c40c
- Add support for exiting on client or service EOF

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 129b5dd
- Better logging for socket services

* Sat May 04 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - cdf92b7
- Check at startup that standard streams are open

* Thu May 02 2024 Ben Grande <ben.grande.b@gmail.com> - 19ed045
- Document rpc-config until skip-service-descriptor

* Thu May 02 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 9e72d82
- Fix SIGUSR1 after stdin_fd closed

* Wed May 01 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - adbf4a2
- Fix build error on redefined _FORTIFY_SOURCE

* Wed May 01 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 8f2539a
- Explain why there is no use after free vulnerability

* Wed May 01 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6d37768
- Restore correct log path

* Wed May 01 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 0fcec31
- Ensure proper RPM dependency ordering

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c2f197c
- Ensure that EOF is propagated to stdout

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 8120940
- Document the file descriptrs for struct process_io_request

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a3bbcb5
- Prefer close() to shutdown()

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - bc71817
- do_fork_exec(): Drop status pipe

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - acda549
- Use close_range() instead of close loop

* Mon Apr 29 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - d9e3a76
- fix_fds(): check that input FDs are okay

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 2844865
- Fix memory leak in load_service_config()

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c801cf3
- Refuse executable service with skip-service-descriptor=true

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - b355ccc
- Forbide skip-service-descriptor=true with explicit username

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 873e77e
- If skip-service-descriptor=true, do not use fork server

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 76790cb
- Avoid leaking vchans

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - e06514b
- Share qrexec-daemon VM -> VM call code with qrexec-client

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 0f7bf45
- Avoid warnings from pytest

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 6fa1106
- Adjust test to reflect reality

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 56fdd7d
- Eradicate VLAs from the codebase

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 82cbe71
- Use calloc() instead of malloc() + memset()

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 696f831
- Avoid pointlessly setting argv[0]

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 930b47d
- Add visibility attributes and use -fvisibility=hidden

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - b8f0031
- Avoid allocating a big buffer for each loop iteration

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 57855c6
- qrexec-daemon: check for valid messages from clients

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 4f1e524
- qrexec-daemon: Do not check service identifier for DEFAULT: keyword

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - e98ed7a
- qrexec-agent: Take advantage of flexible array members

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 3313110
- qrexec-daemon: Take advantage of flexible array members

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - e33f334
- qrexec-daemon: partially validate messages from client

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - ad72712
- Check for empty source domain names

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 71c1ae3
- Ensure consistent treatment of "QUBESRPC" followed by non-space

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - b115494
- Do not skip "nogui:" prefix in agent

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 163597e
- Report correct statuses for service execution failure

* Fri Apr 26 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a9f5e18
- Check for dup2() errors and avoid FD leak

* Fri Apr 26 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a9d11c0
- Do not use a timeout if QREXEC_STARTUP_NOWAIT is set

* Fri Apr 26 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a91949a
- Use _exit() in child process after fork()

* Tue Apr 23 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 652b8f5
- Do not close stdin, stdout, or stderr

* Tue Apr 23 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a0e7438
- Make more functions in agent tests idempotent

* Tue Apr 23 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c01e533
- Implement connections to TCP-based services

* Tue Apr 23 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 6d66051
- Avoid writing to an uninitialized file descriptor

* Tue Apr 23 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 695c3f3
- find_file(): Check for symlinks to /dev/tcp/

